@@ -1,4 +1,5 @@
-from yowsup.stacks import YowStack, YOWSUP_FULL_STACK_DEBUG  as YOWSUP_FULL_STACK
+from yowsup.stacks import YowStack, YOWSUP_CORE_LAYERS, YOWSUP_PROTOCOL_LAYERS_FULL
+from yowsup.layers.axolotl import YowAxolotlLayer
 from .layer import YowsupCliLayer
 from yowsup.common import YowConstants
 from yowsup.layers.network import YowNetworkLayer
@@ -6,16 +7,31 @@ from yowsup.layers.auth import AuthError
 from yowsup.layers.coder import YowCoderLayer
 from yowsup.layers import YowLayerEvent
 from yowsup.layers.auth import YowAuthenticationProtocolLayer
+from yowsup import env
+from yowsup.env import S40YowsupEnv
 import sys
 
 class YowsupCliStack(object):
-    def __init__(self, credentials):
-        self.stack = YowStack(
-            (YowsupCliLayer,) + YOWSUP_FULL_STACK
-        )
+    def __init__(self, credentials, encryptionEnabled = False):
+        if encryptionEnabled:
+            stackStruct = \
+                (YowsupCliLayer,) +\
+                (YOWSUP_PROTOCOL_LAYERS_FULL,) +\
+                (YowAxolotlLayer,) +\
+                YOWSUP_CORE_LAYERS
+
+        else:
+            env.CURRENT_ENV = S40YowsupEnv()
+            stackStruct = \
+                (YowsupCliLayer,) +\
+                (YOWSUP_PROTOCOL_LAYERS_FULL,) +\
+                YOWSUP_CORE_LAYERS
+
+        self.stack = YowStack(stackStruct)
+
         self.stack.setProp(YowNetworkLayer.PROP_ENDPOINT, YowConstants.ENDPOINTS[0])
         self.stack.setProp(YowCoderLayer.PROP_DOMAIN, YowConstants.DOMAIN)
-        self.stack.setProp(YowCoderLayer.PROP_RESOURCE, YowConstants.RESOURCE)
+        self.stack.setProp(YowCoderLayer.PROP_RESOURCE, env.CURRENT_ENV.getResource())
         self.stack.setProp(YowAuthenticationProtocolLayer.PROP_CREDENTIALS, credentials)
 
     def start(self):
