@@ -11,16 +11,16 @@ class YowIqProtocolLayer(YowProtocolLayer):
     def __str__(self):
         return "Iq Layer"
 
+    def onPong(self, protocolTreeNode, pingEntity):
+        self.toUpper(ResultIqProtocolEntity.fromProtocolTreeNode(protocolTreeNode))
+
     def sendIq(self, entity):
         if entity.getXmlns() == "w:p":
+            self._sendIq(entity, self.onPong)
+        elif entity.getXmlns() in ("urn:xmpp:whatsapp:push", "w", "urn:xmpp:whatsapp:account", "encrypt"):
             self.toLower(entity.toProtocolTreeNode())
 
     def recvIq(self, node):
         if node["xmlns"] == "urn:xmpp:ping":
             entity = PongResultIqProtocolEntity(YowConstants.DOMAIN, node["id"])
             self.toLower(entity.toProtocolTreeNode())
-        elif node["type"] == "error":
-            self.toUpper(ErrorIqProtocolEntity.fromProtocolTreeNode(node))
-        elif node["type"] == "result" and not len(node.getAllChildren()):
-            #allowing only unidentifiable result (has no children) iq through this layer. (ex: ping result)
-            self.toUpper(ResultIqProtocolEntity.fromProtocolTreeNode(node))
