@@ -2,12 +2,16 @@ from yowsup.structs import ProtocolEntity, ProtocolTreeNode
 class IqProtocolEntity(ProtocolEntity):
 
     '''
-    <iq type="{{get | set}}" id="{{id}}" xmlns="{{xmlns}}, to={{TO}} from={{FROM}}">
+    <iq type="{{get | set}}" id="{{id}}" xmlns="{{xmlns}}" to="{{TO}}" from="{{FROM}}">
     </iq>
     '''
 
-    TYPES = ("set", "get", "result", "error")
+    TYPE_SET = "set"
+    TYPE_GET = "get"
+    TYPE_ERROR = "error"
+    TYPE_RESULT = "result"
 
+    TYPES = (TYPE_SET, TYPE_GET, TYPE_RESULT, TYPE_ERROR)
     def __init__(self, xmlns = None, _id = None, _type = None, to = None, _from = None):
         super(IqProtocolEntity, self).__init__("iq")
 
@@ -22,8 +26,17 @@ class IqProtocolEntity(ProtocolEntity):
     def getId(self):
         return self._id
 
+    def getType(self):
+        return self._type
+
     def getXmlns(self):
         return self.xmlns
+
+    def getFrom(self):
+        return self._from
+
+    def getTo(self):
+        return self.to
     
     def toProtocolTreeNode(self):
         attribs = {
