@@ -3,3 +3,5 @@ from .message_media_downloadable import DownloadableMediaMessageProtocolEntity
 from .message_media_downloadable_image import ImageDownloadableMediaMessageProtocolEntity
 from .message_media_location import LocationMediaMessageProtocolEntity
 from .message_media_vcard import VCardMediaMessageProtocolEntity
+from .iq_requestupload import RequestUploadIqProtocolEntity
+from .iq_requestupload_result import ResultRequestUploadIqProtocolEntity
