@@ -40,8 +40,8 @@ class MessageProtocolEntity(ProtocolEntity):
     def getTo(self, full = True):
         return self.to if full else self.to.split('@')[0]
 
-    def getParticipant(self):
-        return self.participant
+    def getParticipant(self, full = True):
+        return self.participant if full else self.participant.split('@')[0]
 
     def getNotify(self):
         return self.notify
