@@ -25,6 +25,12 @@ class YowNotificationsProtocolLayer(YowProtocolLayer):
         elif node["type"] == "status":
             self.toUpper(StatusNotificationProtocolEntity.fromProtocolTreeNode(node))
         elif node["type"] == "features":
+            # Not implemented
+            pass
+        elif node["type"] in [ "contacts", "subject", "w:gp2" ]:
+            # Implemented in respectively the protocol_contacts and protocol_groups layer
+            pass
+        elif node["type"] == "contacts":
             pass
         else:
             self.raiseErrorForNode(node)
